from .azureblobmapping import AzureBlobMapping

__all__ = [
    "AzureBlobMapping",
]
